####################
## IMPORTS
import cherrypy
from cherrypy import _cperror

from indigopy import indigoconn as ic
from indigopy import indigodb as idb
from indigopy.basereqhandler import BaseRequestHandler, kTrueStr, kFalseStr, kEmptyStr, kTextPageStr, kHtmlPageStr, kXmlPageStr

####################
# Optional hook to provide a plugin name (will be shown in Event Log)
def PlugInName():
	return u"WD Plugin"

# Optional hook called when the IndigoWebServer first connects to IndigoServer
def IndigoConnected():
	pass

# Optional hook called when the IndigoWebServer disconnect from IndigoServer
def IndigoDisconnected():
	pass

####################
# here to supress the log message
def NullLog(logMessage):
	pass
	
####################
class MyRequestHandler(BaseRequestHandler):
	""" Handles HTTP page requests. """

	####################
	def __init__(self, logFunc, debugLogFunc):
		BaseRequestHandler.__init__(self, logFunc, debugLogFunc)
		
	####################
	def index(self):
		# Push a log message to Indigo's Event Log window.
		logmessage = "WD Custom CGI URL: http://host:port/WD/importData?\n\nUnlike the WD example, you don't need to add an ID or PASSWORD parameter since the IWS is already has protection"
		self._Log(logmessage)
		# Set the HTTP response header Content-Type to show that we're going to be returning plain text (not HTML)
		cherrypy.response.headers['Content-Type'] = 'text/plain'
		# Return the actual content part of the HTTP message
		return logmessage
	index.exposed = True				# exposed = True must be set for handler func to be called


	####################
	def importData(self, **params):
		cherrypy.response.headers['Content-Type'] = 'text/plain'
		saveLogFunc = cherrypy.server.indigoDb._Log
		try:
			cherrypy.server.indigoDb._Log = NullLog
			for param, value in cherrypy.request.params.items():
				if param != "action" and param != "ID" and param != "PASSWORD":
					param = "WD_" + param
					cherrypy.server.indigoDb.VariableSetValue(cherrypy.server.indigoConn, param, value)
		finally:
			cherrypy.server.indigoDb._Log = saveLogFunc
		# Push the log message to Indigo's Event Log window.
		self._Log("WD Weather Data Updated")
		# Return the actual content part of the HTTP message
		return "OK"
	importData.exposed = True        # exposed = True must be set for handler func to be called
